Class: Processing::App
- Inherits:
-
PApplet
- Object
- PApplet
- Processing::App
show all
- Includes:
- Math, HelperMethods
- Defined in:
- lib/jruby_art/app.rb
Overview
All sketches extend this class
Class Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
#blend_color, #buffer, #color, #constrain, #constrained_map, #dist, #find_method, #frame_rate, #grid, #java_self, #key, #key_pressed?, #lerp, #lerp_color, #load_strings, #map, #map1d, #max, #min, #mouse_pressed?, #norm, #proxy_java_fields, #save_strings, #sketch_path, #thread
Constructor Details
#initialize(options = {}) ⇒ App
Since processing-3.0 you should prefer setting the sketch width and height and renderer using the size method in the settings loop of the sketch (as with vanilla processing) but is hidden see created java. Options are no longer relevant, define post_initialize method to use custom options (see Sandi Metz POODR)
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
|
# File 'lib/jruby_art/app.rb', line 97
def initialize(options = {})
super()
post_initialize(options) $app = self
proxy_java_fields
mix_proxy_into_inner_classes
java.lang.Thread.default_uncaught_exception_handler = proc do |_thread_, exception|
puts(exception.class.to_s)
puts(exception.message)
puts(exception.backtrace.map { |trace| "\t#{trace}" })
close
end
run_sketch
end
|
Class Attribute Details
.library_loader ⇒ Object
Handy getters and setters on the class go here:
59
60
61
|
# File 'lib/jruby_art/app.rb', line 59
def library_loader
@library_loader
end
|
.sketch_class ⇒ Object
Handy getters and setters on the class go here:
59
60
61
|
# File 'lib/jruby_art/app.rb', line 59
def sketch_class
@sketch_class
end
|
Class Method Details
.inherited(subclass) ⇒ Object
Keep track of what inherits from the Processing::App, because we’re going to want to instantiate one.
52
53
54
55
|
# File 'lib/jruby_art/app.rb', line 52
def self.inherited(subclass)
super(subclass)
@sketch_class = subclass
end
|
.library_loaded?(library_name) ⇒ Boolean
67
68
69
|
# File 'lib/jruby_art/app.rb', line 67
def library_loaded?(library_name)
library_loader.library_loaded?(library_name)
end
|
.load_java_library(*args) ⇒ Object
75
76
77
|
# File 'lib/jruby_art/app.rb', line 75
def load_java_library(*args)
library_loader.load_java_library(*args)
end
|
.load_libraries(*args) ⇒ Object
Also known as:
load_library
61
62
63
64
|
# File 'lib/jruby_art/app.rb', line 61
def load_libraries(*args)
library_loader ||= LibraryLoader.new
library_loader.load_library(*args)
end
|
.load_ruby_library(*args) ⇒ Object
71
72
73
|
# File 'lib/jruby_art/app.rb', line 71
def load_ruby_library(*args)
library_loader.load_ruby_library(*args)
end
|
.method_added(method_name) ⇒ Object
When certain special methods get added to the sketch, we need to let Processing call them by their expected Java names.
81
82
83
84
|
# File 'lib/jruby_art/app.rb', line 81
def method_added(method_name) return unless METHODS_TO_ALIAS.key?(method_name)
alias_method METHODS_TO_ALIAS[method_name], method_name
end
|
Instance Method Details
#close ⇒ Object
Close and shutter a running sketch. But don’t exit. way of disposing of sketch window…
133
134
135
136
137
138
|
# File 'lib/jruby_art/app.rb', line 133
def close
control_panel.remove if respond_to?(:control_panel)
surface.stopThread
surface.setVisible(false) if surface.isStopped()
dispose
end
|
#exit ⇒ Object
140
141
142
143
|
# File 'lib/jruby_art/app.rb', line 140
def exit
control_panel.remove if respond_to?(:control_panel)
super()
end
|
#library_loaded?(library_name) ⇒ Boolean
87
88
89
|
# File 'lib/jruby_art/app.rb', line 87
def library_loaded?(library_name)
self.class.library_loaded?(library_name)
end
|
#post_initialize(_args) ⇒ Object
126
127
128
|
# File 'lib/jruby_art/app.rb', line 126
def post_initialize(_args)
nil
end
|
#size(*args) ⇒ Object
113
114
115
116
117
118
119
120
|
# File 'lib/jruby_art/app.rb', line 113
def size(*args)
w, h, mode = *args
@width ||= w
@height ||= h
@render_mode ||= mode
import_opengl if /opengl/ =~ mode
super(*args)
end
|
#sketch_class ⇒ Object
46
47
48
|
# File 'lib/jruby_art/app.rb', line 46
def sketch_class
self.class.sketch_class
end
|
#sketch_title(title) ⇒ Object
122
123
124
|
# File 'lib/jruby_art/app.rb', line 122
def sketch_title(title)
surface.setTitle(title)
end
|