Method: Processing::LibraryLoader#load_libraries

Defined in:
lib/jruby_art/library_loader.rb

#load_libraries(*args) ⇒ Object Also known as: load_library

Load a list of Ruby or Java libraries (in that order) Usage: load_libraries :video, :video_event

If a library is put into a ‘library’ folder next to the sketch it will be used instead of the library that ships with vanilla processing (or ide installed), or JRubyArt.



25
26
27
28
29
30
31
# File 'lib/jruby_art/library_loader.rb', line 25

def load_libraries(*args)
  message = 'no such file to load -- %s'
  args.each do |lib|
    loaded = loader(lib)
    raise(LoadError.new, format(message, lib)) unless loaded
  end
end